@@ -24,23 +24,17 @@
 package org.videolan.vlc.gui;
 
 import android.app.SearchManager;
-import android.content.ClipData;
 import android.content.Intent;
-import android.net.Uri;
 import android.os.Bundle;
 import android.support.annotation.Nullable;
 import android.support.v4.app.Fragment;
 import android.support.v4.view.MenuItemCompat;
 import android.support.v7.widget.SearchView;
-import android.view.DragAndDropPermissions;
-import android.view.DragEvent;
 import android.view.Menu;
 import android.view.MenuItem;
 import android.view.View;
 
 import org.videolan.libvlc.RendererItem;
-import org.videolan.libvlc.util.AndroidUtil;
-import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.RendererDelegate;
 import org.videolan.vlc.gui.audio.AudioBrowserFragment;
@@ -51,7 +45,6 @@ import org.videolan.vlc.gui.dialogs.RenderersDialog;
 import org.videolan.vlc.gui.helpers.UiTools;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.interfaces.Filterable;
-import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.util.AndroidDevices;
 
 public class ContentActivity extends AudioPlayerContainerActivity implements SearchView.OnQueryTextListener, MenuItemCompat.OnActionExpandListener, RendererDelegate.RendererListener, RendererDelegate.RendererPlayer {
@@ -64,37 +57,7 @@ public class ContentActivity extends AudioPlayerContainerActivity implements Sea
     @Override
     protected void onPostCreate(@Nullable Bundle savedInstanceState) {
         super.onPostCreate(savedInstanceState);
-        final View view = AndroidUtil.isNougatOrLater ? getWindow().peekDecorView() : null;
-        if (view != null) view.setOnDragListener(new View.OnDragListener() {
-            @Override
-            public boolean onDrag(View v, DragEvent event) {
-                switch (event.getAction()) {
-                    case DragEvent.ACTION_DRAG_STARTED:
-                        return true;
-                    case DragEvent.ACTION_DROP:
-                        final ClipData clipData = event.getClipData();
-                        if (clipData == null) return false;
-                        final int itemsCount = clipData.getItemCount();
-                        for (int i = 0; i < itemsCount; i++) {
-                            final DragAndDropPermissions permissions = requestDragAndDropPermissions(event);
-                            if (permissions != null)  {
-                                final ClipData.Item item = clipData.getItemAt(i);
-                                if (item.getUri() != null) MediaUtils.openUri(ContentActivity.this, item.getUri());
-                                else if (item.getText() != null) {
-                                    final Uri uri = Uri.parse(item.getText().toString());
-                                    final MediaWrapper media = new MediaWrapper(uri);
-                                    if (!"file".equals(uri.getScheme())) media.setType(MediaWrapper.TYPE_STREAM);
-                                    MediaUtils.openMedia(ContentActivity.this, media);
-                                }
-                                return true;
-                            }
-                        }
-                        return false;
-                    default:
-                        return false;
-                }
-            }
-        });
+        UiTools.setOnDragListener(this);
     }
 
     @Override
@@ -241,7 +204,12 @@ public class ContentActivity extends AudioPlayerContainerActivity implements Sea
 
     @Override
     public void onRenderersChanged(boolean empty) {
+        if (showRenderers != empty) return;
         showRenderers = !empty;
+        if (empty && !AndroidDevices.isChromeBook) {
+            RendererDelegate.INSTANCE.selectRenderer(null);
+            if (mService != null) mService.setRenderer(null);
+        }
         supportInvalidateOptionsMenu();
     }
 
